@@ -9,4 +9,4 @@ api = TikTokApi.get_instance(
 def test_get_music_object_full_by_api():
     music_id = "6819262113299565318"
     res = api.get_music_object_full_by_api(music_id)
-    assert res['music']['id'] == music_id
+    assert res["music"]["id"] == music_id
